#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
#include <iostream>

using namespace std;

int numvec (int length, int *vec1, int *vec2)
//  computes, in how many components two vectors coincide
  {
	int i;
	int numeq=0; 

  for (i=0; i<length; i++)
    {
		if (vec1[i] == vec2[i])
		  numeq++;
		}

	return numeq;
	}

bool diffstrat (int length1, int length2, int **answermat, int &first, int &second)
// checks whether there are two differents possible secrets 
// which have the same combination of answers in this strategy 
  {
	int i,j,s;
	bool dop=true;
  
	first = 0;
	second = 0;

  for (i=0; i<length1; i++)
	  {
		for (j=i+1; j<length1; j++)
		  {
			if (numvec(length2,answermat[i],answermat[j]) == length2)
			// if two answer combinations coincide in all components,
			// they are saved, and the strategy is not feasible
				 {
			  dop = false;
				first = i; 
				second = j;
				i=length1;
				break; 
			  }
      }
		}	

	return dop;
	}

bool strategy_check (int p, int c, int questions, int **strategy, bool output )
// checks whether a given strategy is feasible,	
// if not and if "output=true" is set, it outputs two possible secrets 
// which have the same combination of answers in this strategy
	{
	int i,j,s;
	int iauxil;
	bool optstrat;
	int first;
	int second;
	int numsec;

	int **answermat;
	// gives for each possible secret the answer of the strategy to the corresponding question
	int **pmat;
  // the matrix of all possible secrets

  numsec = (int) floor(pow(c,p)+0.5);
	// the number of possible secrets

  answermat = (int**) malloc(sizeof(int*) * numsec);
  pmat = (int**) malloc(sizeof(int*) * numsec);

	if (answermat == NULL)
	  {
		cout << "Error1" << endl;
		exit(1);
		}

  for (s=0; s<numsec; s++)
	  {
	  answermat[s] = (int*) malloc(sizeof(int) * questions);
		if (answermat[s] == NULL)
		  {
			cout << "Error2" << endl;
			exit(1);
			}
		}

	if (pmat == NULL)
	  {
		cout << "Error3" << endl;
		exit(1);
		}

  for (s=0; s<numsec; s++)
	  {
	  pmat[s] = (int*) malloc(sizeof(int) * p);
		if (pmat[s] == NULL)
		  {
			cout << "Error4" << endl;
			exit(1);
			}
		}
  for (s=0; s<numsec; s++)
    {
		for (j=0; j<p; j++)
		  pmat[s][j] = 0;

		iauxil = s;

    j=p-1;
    while (j>=0)
		  {
			pmat[s][j] = iauxil % c;
			iauxil /= c;
			j--;
			}

		for (i=0; i<questions; i++)
			answermat[s][i] = numvec(p, strategy[i], pmat[s]);
		}
   
  optstrat = diffstrat (numsec,questions,answermat,first,second);

	if (output)
	  {
		cout << "optstrat=" << optstrat << endl;
		if (optstrat == false)
			{
			cout << "a: ";
			cout << "Possible secret: ";
			for (j=0; j<p; j++)
				cout << pmat[first][j] << " ";
			cout << endl;	

			cout << "Answers: ";
			for (i=0; i<questions; i++)
				cout << answermat[first][i] << " ";
			cout << endl;	
			cout << endl;	

			cout << "b: ";
			cout << "Possible secret: ";
			for (j=0; j<p; j++)
				cout << pmat[second][j] << " ";
			cout << endl;	

			cout << "Answers: ";
			for (i=0; i<questions; i++)
				cout << answermat[second][i] << " ";
			cout << endl;	

			cout << endl;	
			}
    }

  for (s=0; s<numsec; s++)
	   free (answermat[s]);
	free (answermat);

  for (s=0; s<numsec; s++)
	   free (pmat[s]);
	free (pmat);

	return optstrat;
  }

int main (int argc, char **argv)
  {
	int i,j;
	int c;
	int p;
	int questions;
	int version;
	int optstrat;
	int **strategy;
  FILE *fname;
  char* filename;
	char* ep;
  char* y;

  version = 0;

  filename = (char*) malloc(sizeof(char) * 100);
	if (filename == NULL)
	  {
		cout << "Error5" << endl;
		exit(1);
		}


	if (argc >= 2)
		{
		y = argv[1];
		version = strtoul(y, &ep, 10);
	  }

  if (version == 0 && argc == 1)
	  {
		cout << "Error6" << endl;
		cout << "Usage: 'a.out 0 strategy' or 'a.out case_number'" << endl;
		exit(1);
		}

  switch (version)
	  {
		case 0:
			strcpy (filename,argv[2]);
			if (fname = fopen (filename,"r"))
				{
				}
			else
				{
				cout << "Error7" << endl;
				cout << "File cannot be openend!" << endl;
				exit(1);
				}

			fscanf (fname,"%d \n", &p);
			fscanf (fname,"%d \n", &c);
			fscanf (fname,"%d \n", &questions);
		break;
    case 1:
		  p=3;
			c=2;
			questions=2;
		break;
    case 2:
		  p=4;
			c=2;
			questions=3;
		break;
    case 3:
		  p=5;
			c=2;
			questions=3;
		break;
    case 4:
		  p=6;
			c=2;
			questions=4;
		break;
		case 5:
			p=7;		
			c=2;
			questions=5;
		break;
		case 6:
		  p=3;
			c=3;
			questions=3;
		break;
    case 7:
		  p=4;
			c=3;
			questions=4;
		break;
    case 8:
		  p=5;
			c=3;
			questions=4;
		break;
		case 9:
		  p=3;
			c=4;
			questions=5;
		break;
		}

  strategy = (int**) malloc(sizeof(int*) * questions);

	if (strategy == NULL)
	  {
		cout << "Error7" << endl;
		exit(1);
		}

  for (i=0; i<questions; i++)
	  {
	  strategy[i] = (int*) malloc(sizeof(int) * p);
		if (strategy[i] == NULL)
		  {
			cout << "Error8" << endl;
			exit(1);
			}
		}

	int s1,s2,s3,s4,s5,s6,s7,s8,s9,s10,s11,s12,s13,s14;
	int s15,s16,s17,s18,s19,s20,s21,s22,s23,s24,s25,s26,s27,s28;
  int lbound,ubound;

	switch (version)
	  {
    case 0:
			for (i=0; i<questions; i++)
				for (j=0; j<p; j++)
					fscanf (fname,"%d \n", &strategy[i][j]);

			fclose (fname);
			strategy_check (p, c, questions, strategy, true);
		break;
		case 1:
			// p=3, c=2, questions=2
			// Answer: no strategy
			strategy[0][0] = 0;
			strategy[0][1] = 0;
			strategy[0][2] = 0;
			lbound=0;
			ubound=1;
			for (s1=lbound; s1<=ubound; s1++)
				for (s2=lbound; s2<=ubound; s2++)
					for (s3=lbound; s3<=ubound; s3++)
						{
						strategy[1][0] = s1;
						strategy[1][1] = s2;
						strategy[1][2] = s3;
						optstrat = strategy_check (p, c, questions, strategy, false);
						if (optstrat == true)
							{
							cout << "s1=" << s1 << endl;
							cout << "s2=" << s2 << endl;
							cout << "s3=" << s3 << endl;
							exit(1);
							}
						}
			cout << "No solution" << endl;
		break;
		case 2:
			// p=4, c=2, questions=3
			// Answer: no strategy
			strategy[0][0] = 0;
			strategy[0][1] = 0;
			strategy[0][2] = 0;
			strategy[0][3] = 0;
			lbound=0;
			ubound=1;
			for (s1=lbound; s1<=ubound; s1++)
				for (s2=lbound; s2<=ubound; s2++)
					for (s3=lbound; s3<=ubound; s3++)
						for (s4=lbound; s4<=ubound; s4++)
							for (s5=lbound; s5<=ubound; s5++)
								for (s6=lbound; s6<=ubound; s6++)
									for (s7=lbound; s7<=ubound; s7++)
										for (s8=lbound; s8<=ubound; s8++)
											{
											strategy[1][0] = s1;
											strategy[1][1] = s2;
											strategy[1][2] = s3;
											strategy[1][3] = s4;
											strategy[2][0] = s5;
											strategy[2][1] = s6;
											strategy[2][2] = s7;
											strategy[2][3] = s8;
											optstrat = strategy_check (p, c, questions, strategy, false);
											if (optstrat == true)
												{
												cout << "s1=" << s1 << endl;
												cout << "s2=" << s2 << endl;
												cout << "s3=" << s3 << endl;
												cout << "s4=" << s4 << endl;
												cout << "s5=" << s5 << endl;
												cout << "s6=" << s6 << endl;
												cout << "s7=" << s7 << endl;
												cout << "s8=" << s8 << endl;
												exit(1);
												}
											}
			cout << "No solution" << endl;
		break;
		case 3:
			// p=5, c=2, questions=3
			// Answer: no strategy
			strategy[0][0] = 0;
			strategy[0][1] = 0;
			strategy[0][2] = 0;
			strategy[0][3] = 0;
			strategy[0][4] = 0;
			lbound=0;
			ubound=1;
			for (s1=lbound; s1<=ubound; s1++)
				for (s2=lbound; s2<=ubound; s2++)
					for (s3=lbound; s3<=ubound; s3++)
						for (s4=lbound; s4<=ubound; s4++)
							for (s5=lbound; s5<=ubound; s5++)
								for (s6=lbound; s6<=ubound; s6++)
									for (s7=lbound; s7<=ubound; s7++)
										for (s8=lbound; s8<=ubound; s8++)
											for (s9=lbound; s9<=ubound; s9++)
												for (s10=lbound; s10<=ubound; s10++)
													{
													strategy[1][0] = s1;
													strategy[1][1] = s2;
													strategy[1][2] = s3;
													strategy[1][3] = s4;
													strategy[1][4] = s5;
													strategy[2][0] = s6;
													strategy[2][1] = s7;
													strategy[2][2] = s8;
													strategy[2][3] = s9;
													strategy[2][4] = s10;
													optstrat = strategy_check (p, c, questions, strategy, false);
													if (optstrat == true)
														{
														cout << "s1=" << s1 << endl;
														cout << "s2=" << s2 << endl;
														cout << "s3=" << s3 << endl;
														cout << "s4=" << s4 << endl;
														cout << "s5=" << s5 << endl;
														cout << "s6=" << s6 << endl;
														cout << "s7=" << s7 << endl;
														cout << "s8=" << s8 << endl;
														cout << "s9=" << s9 << endl;
														cout << "s10=" << s10 << endl;
														exit(1);
														}
													}
			cout << "No solution" << endl;
		break;
		case 4:
			// p=6, c=2, questions=4
			// Answer: no strategy
			strategy[0][0] = 0;
			strategy[0][1] = 0;
			strategy[0][2] = 0;
			strategy[0][3] = 0;
			strategy[0][4] = 0;
			strategy[0][5] = 0;
			lbound=0;
			ubound=1;
			for (s1=lbound; s1<=ubound; s1++)
				for (s2=lbound; s2<=ubound; s2++)
					for (s3=lbound; s3<=ubound; s3++)
						for (s4=lbound; s4<=ubound; s4++)
							for (s5=lbound; s5<=ubound; s5++)
								for (s6=lbound; s6<=ubound; s6++)
									for (s7=lbound; s7<=ubound; s7++)
										for (s8=lbound; s8<=ubound; s8++)
											for (s9=lbound; s9<=ubound; s9++)
												for (s10=lbound; s10<=ubound; s10++)
													for (s11=lbound; s11<=ubound; s11++)
														for (s12=lbound; s12<=ubound; s12++)
															for (s13=lbound; s13<=ubound; s13++)
																for (s14=lbound; s14<=ubound; s14++)
																	for (s15=lbound; s15<=ubound; s15++)
																		for (s16=lbound; s16<=ubound; s16++)
																			for (s17=lbound; s17<=ubound; s17++)
																				for (s18=lbound; s18<=ubound; s18++)
																					{
																					strategy[1][0] = s1;
																					strategy[1][1] = s2;
																					strategy[1][2] = s3;
																					strategy[1][3] = s4;
																					strategy[1][4] = s5;
																					strategy[1][5] = s6;
																					strategy[2][0] = s7;
																					strategy[2][1] = s8;
																					strategy[2][2] = s9;
																					strategy[2][3] = s10;
																					strategy[2][4] = s11;
																					strategy[2][5] = s12;
																					strategy[3][0] = s13;
																					strategy[3][1] = s14;
																					strategy[3][2] = s15;
																					strategy[3][3] = s16;
																					strategy[3][4] = s17;
																					strategy[3][5] = s18;
																					optstrat = strategy_check (p, c, questions, strategy, false);
																					if (optstrat == true)
																						{
																						cout << "s1=" << s1 << endl;
																						cout << "s2=" << s2 << endl;
																						cout << "s3=" << s3 << endl;
																						cout << "s4=" << s4 << endl;
																						cout << "s5=" << s5 << endl;
																						cout << "s6=" << s6 << endl;
																						cout << "s7=" << s7 << endl;
																						cout << "s8=" << s8 << endl;
																						cout << "s9=" << s9 << endl;
																						cout << "s10=" << s10 << endl;
																						cout << "s11=" << s11 << endl;
																						cout << "s12=" << s12 << endl;
																						cout << "s13=" << s13 << endl;
																						cout << "s14=" << s14 << endl;
																						cout << "s15=" << s15 << endl;
																						cout << "s16=" << s16 << endl;
																						cout << "s17=" << s17 << endl;
																						cout << "s18=" << s18 << endl;
																						exit(1);
																						}
																					}
			cout << "No solution" << endl;
		break;
		case 5:
			// p=7, c=2, questions=5
			// Answer: no strategy
			strategy[0][0] = 0;
			strategy[0][1] = 0;
			strategy[0][2] = 0;
			strategy[0][3] = 0;
			strategy[0][4] = 0;
			strategy[0][5] = 0;
			strategy[0][6] = 0;
			lbound=0;
			ubound=1;
			for (s1=lbound; s1<=ubound; s1++)
				for (s2=lbound; s2<=ubound; s2++)
					for (s3=lbound; s3<=ubound; s3++)
						for (s4=lbound; s4<=ubound; s4++)
							for (s5=lbound; s5<=ubound; s5++)
								for (s6=lbound; s6<=ubound; s6++)
									for (s7=lbound; s7<=ubound; s7++)
										for (s8=lbound; s8<=ubound; s8++)
											for (s9=lbound; s9<=ubound; s9++)
												for (s10=lbound; s10<=ubound; s10++)
													for (s11=lbound; s11<=ubound; s11++)
														for (s12=lbound; s12<=ubound; s12++)
															for (s13=lbound; s13<=ubound; s13++)
																for (s14=lbound; s14<=ubound; s14++)
																	for (s15=lbound; s15<=ubound; s15++)
																		for (s16=lbound; s16<=ubound; s16++)
																			for (s17=lbound; s17<=ubound; s17++)
																				for (s18=lbound; s18<=ubound; s18++)
																					for (s19=lbound; s19<=ubound; s19++)
																						for (s20=lbound; s20<=ubound; s20++)
																							for (s21=lbound; s21<=ubound; s21++)
																								for (s22=lbound; s22<=ubound; s22++)
																									for (s23=lbound; s23<=ubound; s23++)
																										for (s24=lbound; s24<=ubound; s24++)
																											for (s25=lbound; s25<=ubound; s25++)
																												for (s26=lbound; s26<=ubound; s26++)
																													for (s27=lbound; s27<=ubound; s27++)
																														for (s28=lbound; s28<=ubound; s28++)
																															{
																															strategy[1][0] = s1;
																															strategy[1][1] = s2;
																															strategy[1][2] = s3;
																															strategy[1][3] = s4;
																															strategy[1][4] = s5;
																															strategy[1][5] = s6;
																															strategy[1][6] = s7;
																															strategy[2][0] = s8;
																															strategy[2][1] = s9;
																															strategy[2][2] = s10;
																															strategy[2][3] = s11;
																															strategy[2][4] = s12;
																															strategy[2][5] = s13;
																															strategy[2][6] = s14;
																															strategy[3][0] = s15;
																															strategy[3][1] = s16;
																															strategy[3][2] = s17;
																															strategy[3][3] = s18;
																															strategy[3][4] = s19;
																															strategy[3][5] = s20;
																															strategy[3][6] = s21;
																															strategy[4][0] = s22;
																															strategy[4][1] = s23;
																															strategy[4][2] = s24;
																															strategy[4][3] = s25;
																															strategy[4][4] = s26;
																															strategy[4][5] = s27;
																															strategy[4][6] = s28;
																															optstrat = strategy_check (p, c, questions, strategy, false);
																															if (optstrat == true)
																																{
																																cout << "s1=" << s1 << endl;
																																cout << "s2=" << s2 << endl;
																																cout << "s3=" << s3 << endl;
																																cout << "s4=" << s4 << endl;
																																cout << "s5=" << s5 << endl;
																																cout << "s6=" << s6 << endl;
																																cout << "s7=" << s7 << endl;
																																cout << "s8=" << s8 << endl;
																																cout << "s9=" << s9 << endl;
																																cout << "s10=" << s10 << endl;
																																cout << "s11=" << s11 << endl;
																																cout << "s12=" << s12 << endl;
																																cout << "s13=" << s13 << endl;
																																cout << "s14=" << s14 << endl;
																																cout << "s15=" << s15 << endl;
																																cout << "s16=" << s16 << endl;
																																cout << "s17=" << s17 << endl;
																																cout << "s18=" << s18 << endl;
																																cout << "s19=" << s19 << endl;
																																cout << "s20=" << s20 << endl;
																																cout << "s21=" << s21 << endl;
																																cout << "s22=" << s22 << endl;
																																cout << "s23=" << s23 << endl;
																																cout << "s24=" << s24 << endl;
																																cout << "s25=" << s25 << endl;
																																cout << "s26=" << s26 << endl;
																																cout << "s27=" << s27 << endl;
																																cout << "s28=" << s28 << endl;
																																exit(1);
																																}
																															}
													cout << "No solution" << endl;
		break;
		case 6:
			// p=3, c=3, questions=3
			// Answer: no strategy
			strategy[0][0] = s1;
			strategy[0][1] = s2;
			strategy[0][2] = s3;
			lbound=0;
			ubound=2;
			for (s1=lbound; s1<=ubound; s1++)
				for (s2=lbound; s2<=ubound; s2++)
					for (s3=lbound; s3<=ubound; s3++)
						for (s4=lbound; s4<=ubound; s4++)
							for (s5=lbound; s5<=ubound; s5++)
								for (s6=lbound; s6<=ubound; s6++)
									{
									strategy[1][0] = s1;
									strategy[1][1] = s2;
									strategy[1][2] = s3;
									strategy[2][0] = s4;
									strategy[2][1] = s5;
									strategy[2][2] = s6;
									optstrat = strategy_check (p, c, questions, strategy, false);
									if (optstrat == true)
										{
										cout << "s1=" << s1 << endl;
										cout << "s2=" << s2 << endl;
										cout << "s3=" << s3 << endl;
										cout << "s4=" << s4 << endl;
										cout << "s5=" << s5 << endl;
										cout << "s6=" << s6 << endl;
										exit(1);
										}
									}
			cout << "No solution" << endl;
		break;
		case 7:
			// p=4, c=3, questions=4
			// Answer: no strategy
			strategy[0][0] = 0;
			strategy[0][1] = 0;
			strategy[0][2] = 0;
			strategy[0][3] = 0;
			lbound=0;
			ubound=2;
			for (s1=lbound; s1<=ubound; s1++)
				for (s2=lbound; s2<=ubound; s2++)
					for (s3=lbound; s3<=ubound; s3++)
						for (s4=lbound; s4<=ubound; s4++)
							for (s5=lbound; s5<=ubound; s5++)
								for (s6=lbound; s6<=ubound; s6++)
									for (s7=lbound; s7<=ubound; s7++)
										for (s8=lbound; s8<=ubound; s8++)
											for (s9=lbound; s9<=ubound; s9++)
												for (s10=lbound; s10<=ubound; s10++)
													for (s11=lbound; s11<=ubound; s11++)
														for (s12=lbound; s12<=ubound; s12++)
															{
															strategy[1][0] = s1;
															strategy[1][1] = s2;
															strategy[1][2] = s3;
															strategy[1][3] = s4;
															strategy[2][0] = s5;
															strategy[2][1] = s6;
															strategy[2][2] = s7;
															strategy[2][3] = s8;
															strategy[3][0] = s9;
															strategy[3][1] = s10;
															strategy[3][2] = s11;
															strategy[3][3] = s12;
															optstrat = strategy_check (p, c, questions, strategy, false);
															if (optstrat == true)
																{
																cout << "s1=" << s1 << endl;
																cout << "s2=" << s2 << endl;
																cout << "s3=" << s3 << endl;
																cout << "s4=" << s4 << endl;
																cout << "s5=" << s5 << endl;
																cout << "s6=" << s6 << endl;
																cout << "s7=" << s7 << endl;
																cout << "s8=" << s8 << endl;
																cout << "s9=" << s9 << endl;
																cout << "s10=" << s10 << endl;
																cout << "s11=" << s11 << endl;
																cout << "s12=" << s12 << endl;
																exit(1);
																}
															}
			cout << "No solution" << endl;
		break;
		case 8:
			// p=5, c=3, questions=4
			// Answer: no strategy
			strategy[0][0] = 0;
			strategy[0][1] = 0;
			strategy[0][2] = 0;
			strategy[0][3] = 0;
			strategy[0][4] = 0;
			lbound=0;
			ubound=2;
			for (s1=lbound; s1<=ubound; s1++)
				for (s2=lbound; s2<=ubound; s2++)
					for (s3=lbound; s3<=ubound; s3++)
						for (s4=lbound; s4<=ubound; s4++)
							for (s5=lbound; s5<=ubound; s5++)
								for (s6=lbound; s6<=ubound; s6++)
									for (s7=lbound; s7<=ubound; s7++)
										for (s8=lbound; s8<=ubound; s8++)
											for (s9=lbound; s9<=ubound; s9++)
												for (s10=lbound; s10<=ubound; s10++)
													for (s11=lbound; s11<=ubound; s11++)
														for (s12=lbound; s12<=ubound; s12++)
															for (s13=lbound; s13<=ubound; s13++)
																for (s14=lbound; s14<=ubound; s14++)
																	for (s15=lbound; s15<=ubound; s15++)
																		{
																		strategy[1][0] = s1;
																		strategy[1][1] = s2;
																		strategy[1][2] = s3;
																		strategy[1][3] = s4;
																		strategy[1][4] = s5;
																		strategy[2][0] = s6;
																		strategy[2][1] = s7;
																		strategy[2][2] = s8;
																		strategy[2][3] = s9;
																		strategy[2][4] = s10;
																		strategy[3][0] = s11;
																		strategy[3][1] = s12;
																		strategy[3][2] = s13;
																		strategy[3][3] = s14;
																		strategy[3][4] = s15;
																		optstrat = strategy_check (p, c, questions, strategy, false);
																		if (optstrat == true)
																			{
																			cout << "s1=" << s1 << endl;
																			cout << "s2=" << s2 << endl;
																			cout << "s3=" << s3 << endl;
																			cout << "s4=" << s4 << endl;
																			cout << "s5=" << s5 << endl;
																			cout << "s6=" << s6 << endl;
																			cout << "s7=" << s7 << endl;
																			cout << "s8=" << s8 << endl;
																			cout << "s9=" << s9 << endl;
																			cout << "s10=" << s10 << endl;
																			cout << "s11=" << s11 << endl;
																			cout << "s12=" << s12 << endl;
																			cout << "s13=" << s13 << endl;
																			cout << "s14=" << s14 << endl;
																			cout << "s15=" << s15 << endl;
																			exit(1);
																			}
																		}
			cout << "No solution" << endl;
		break;
		case 9:
			// p=3, c=4, questions=5
			// Answer: no strategy
			strategy[0][0] = 0;
			strategy[0][1] = 0;
			strategy[0][2] = 0;
			lbound=0;
			ubound=3;
			for (s1=lbound; s1<=ubound; s1++)
				for (s2=lbound; s2<=ubound; s2++)
					for (s3=lbound; s3<=ubound; s3++)
						for (s4=lbound; s4<=ubound; s4++)
							for (s5=lbound; s5<=ubound; s5++)
								for (s6=lbound; s6<=ubound; s6++)
									for (s7=lbound; s7<=ubound; s7++)
										for (s8=lbound; s8<=ubound; s8++)
											for (s9=lbound; s9<=ubound; s9++)
												for (s10=lbound; s10<=ubound; s10++)
													for (s11=lbound; s11<=ubound; s11++)
														for (s12=lbound; s12<=ubound; s12++)
															{
															strategy[1][0] = s1;
															strategy[1][1] = s2;
															strategy[1][2] = s3;
															strategy[2][0] = s4;
															strategy[2][1] = s5;
															strategy[2][2] = s6;
															strategy[3][0] = s7;
															strategy[3][1] = s8;
															strategy[3][2] = s9;
															strategy[4][0] = s10;
															strategy[4][1] = s11;
															strategy[4][2] = s12;
															optstrat = strategy_check (p, c, questions, strategy, false);
															if (optstrat == true)
																{
																cout << "s1=" << s1 << endl;
																cout << "s2=" << s2 << endl;
																cout << "s3=" << s3 << endl;
																cout << "s4=" << s4 << endl;
																cout << "s5=" << s5 << endl;
																cout << "s6=" << s6 << endl;
																cout << "s7=" << s7 << endl;
																cout << "s8=" << s8 << endl;
																cout << "s9=" << s9 << endl;
																cout << "s10=" << s10 << endl;
																cout << "s11=" << s11 << endl;
																cout << "s12=" << s12 << endl;
																exit(1);
																}
															}
			cout << "No solution" << endl;
		break;
	}

  for (i=0; i<questions; i++)
	   free (strategy[i]);
	free (strategy);

  free (filename);

	return 1;
	}
